==> ejc-businessplan-impl-3.0.0-20220225.080726-13-sources.jar: com/ejianc/business/busniessplan/vo/OrgstructureVO.java <==
package com.ejianc.business.busniessplan.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.busniessplan.vo.OrgstructuredetailVO;

/**
 * 项目商务组织架构
 * 
 * @author generator
 * 
 */
public class OrgstructureVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.String contractManageMember; // 合约管理
    private java.lang.String preSettlementMember; // 预结算
    private java.lang.String costManageMember; // 成本管理岗
    private java.lang.Long agentId; // 经办人
    private java.lang.String agentName; // 经办人姓名
    private java.lang.String busManager; // 项目商务经理
    private java.lang.String busManageDepManager; // 商务管理部部门经理
    private java.lang.String busManageDep; // 项目商务管理部
    private java.lang.Integer allocatePersonnelNum; // 配置人员数
    private java.lang.String remarks; // 备注
    
    private List<OrgstructuredetailVO> orgstructuredetailEntities = new ArrayList<>(); // 项目商务组织架构子表

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.String getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.String operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 合约管理
     */
    public java.lang.String getContractManageMember() {
        return contractManageMember;
    }

    /**
     * 合约管理
     */
    public void setContractManageMember(java.lang.String contractManageMember) {
        this.contractManageMember = contractManageMember;
    }
    /**
     * 预结算
     */
    public java.lang.String getPreSettlementMember() {
        return preSettlementMember;
    }

    /**
     * 预结算
     */
    public void setPreSettlementMember(java.lang.String preSettlementMember) {
        this.preSettlementMember = preSettlementMember;
    }
    /**
     * 成本管理岗
     */
    public java.lang.String getCostManageMember() {
        return costManageMember;
    }

    /**
     * 成本管理岗
     */
    public void setCostManageMember(java.lang.String costManageMember) {
        this.costManageMember = costManageMember;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 项目商务经理
     */
    public java.lang.String getBusManager() {
        return busManager;
    }

    /**
     * 项目商务经理
     */
    public void setBusManager(java.lang.String busManager) {
        this.busManager = busManager;
    }
    /**
     * 商务管理部部门经理
     */
    public java.lang.String getBusManageDepManager() {
        return busManageDepManager;
    }

    /**
     * 商务管理部部门经理
     */
    public void setBusManageDepManager(java.lang.String busManageDepManager) {
        this.busManageDepManager = busManageDepManager;
    }
    /**
     * 项目商务管理部
     */
    public java.lang.String getBusManageDep() {
        return busManageDep;
    }

    /**
     * 项目商务管理部
     */
    public void setBusManageDep(java.lang.String busManageDep) {
        this.busManageDep = busManageDep;
    }
    /**
     * 配置人员数
     */
    public java.lang.Integer getAllocatePersonnelNum() {
        return allocatePersonnelNum;
    }

    /**
     * 配置人员数
     */
    public void setAllocatePersonnelNum(java.lang.Integer allocatePersonnelNum) {
        this.allocatePersonnelNum = allocatePersonnelNum;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
     /**
      * 项目商务组织架构子表
      */
     public List<OrgstructuredetailVO> getOrgstructuredetailEntities() {
        return orgstructuredetailEntities;
     }

     /**
      * 项目商务组织架构子表
      */
     public void setOrgstructuredetailEntities(List<OrgstructuredetailVO> orgstructuredetailEntities) {
        this.orgstructuredetailEntities = orgstructuredetailEntities;
     }
}

==> ejc-businessplan-impl-3.0.0-20241021.063348-193-sources.jar: com/ejianc/business/busniessplan/vo/OrgstructureVO.java <==
package com.ejianc.business.busniessplan.vo;

import java.util.List;
import java.util.ArrayList;

import com.ejianc.business.record.vo.RecordOrgstructureVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 项目商务组织架构
 * 
 * @author generator
 * 
 */
public class OrgstructureVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.String contractManageMember; // 合约管理
    private java.lang.String preSettlementMember; // 预结算
    private java.lang.String costManageMember; // 成本管理岗
    private java.lang.Long agentId; // 经办人
    private java.lang.String agentName; // 经办人姓名
    private java.lang.String busManager; // 项目商务经理
    private java.lang.String busManageDepManager; // 商务管理部部门经理
    private java.lang.String busManageDep; // 项目商务管理部
    private java.lang.Integer allocatePersonnelNum; // 配置人员数
    private java.lang.String remarks; // 备注

    private java.lang.String createTimeShow; // 创建时间文本显示
    private java.lang.String billStateStr; // 单据状态文本显示
    private java.lang.String sort; // 序号
    
    private List<OrgstructuredetailVO> orgstructuredetailEntities = new ArrayList<>(); // 项目商务组织架构子表
    private List<RecordOrgstructureVO> recordOrgstructureList = new ArrayList<>(); // 历史信息

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.String getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.String operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 合约管理
     */
    public java.lang.String getContractManageMember() {
        return contractManageMember;
    }

    /**
     * 合约管理
     */
    public void setContractManageMember(java.lang.String contractManageMember) {
        this.contractManageMember = contractManageMember;
    }
    /**
     * 预结算
     */
    public java.lang.String getPreSettlementMember() {
        return preSettlementMember;
    }

    /**
     * 预结算
     */
    public void setPreSettlementMember(java.lang.String preSettlementMember) {
        this.preSettlementMember = preSettlementMember;
    }
    /**
     * 成本管理岗
     */
    public java.lang.String getCostManageMember() {
        return costManageMember;
    }

    /**
     * 成本管理岗
     */
    public void setCostManageMember(java.lang.String costManageMember) {
        this.costManageMember = costManageMember;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 项目商务经理
     */
    public java.lang.String getBusManager() {
        return busManager;
    }

    /**
     * 项目商务经理
     */
    public void setBusManager(java.lang.String busManager) {
        this.busManager = busManager;
    }
    /**
     * 商务管理部部门经理
     */
    public java.lang.String getBusManageDepManager() {
        return busManageDepManager;
    }

    /**
     * 商务管理部部门经理
     */
    public void setBusManageDepManager(java.lang.String busManageDepManager) {
        this.busManageDepManager = busManageDepManager;
    }
    /**
     * 项目商务管理部
     */
    public java.lang.String getBusManageDep() {
        return busManageDep;
    }

    /**
     * 项目商务管理部
     */
    public void setBusManageDep(java.lang.String busManageDep) {
        this.busManageDep = busManageDep;
    }
    /**
     * 配置人员数
     */
    public java.lang.Integer getAllocatePersonnelNum() {
        return allocatePersonnelNum;
    }

    /**
     * 配置人员数
     */
    public void setAllocatePersonnelNum(java.lang.Integer allocatePersonnelNum) {
        this.allocatePersonnelNum = allocatePersonnelNum;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
     /**
      * 项目商务组织架构子表
      */
     public List<OrgstructuredetailVO> getOrgstructuredetailEntities() {
        return orgstructuredetailEntities;
     }

     /**
      * 项目商务组织架构子表
      */
     public void setOrgstructuredetailEntities(List<OrgstructuredetailVO> orgstructuredetailEntities) {
        this.orgstructuredetailEntities = orgstructuredetailEntities;
     }

    public List<RecordOrgstructureVO> getRecordOrgstructureList() {
        return recordOrgstructureList;
    }

    public void setRecordOrgstructureList(List<RecordOrgstructureVO> recordOrgstructureList) {
        this.recordOrgstructureList = recordOrgstructureList;
    }
}
